# rlgym-tools
Extra tools for use with the [RLGym](https://github.com/lucas-emery/RLGym) library.

Contains many options for the RLGym configuration objects:
- Action parsers
- Done conditions
- Obs builders
- Reward functions
- Shared info providers
- State mutators

As well as other utilities like special math functions and replay file parsing.

Community contributions are welcome!

Check out the [RLGym wiki](https://rlgym.github.io/) for more info: 

## Installation
`pip install -U rlgym-tools`
